# Copyright 1999-2022 Gentoo Authors
# Distributed under the terms of the GNU General Public License v2

EAPI=7

MY_P="${PN/-bin/}_${PV}"

inherit systemd

DESCRIPTION="This is a sample skeleton ebuild file"
HOMEPAGE="https://joinmobilizon.org"
SRC_URI="https://packages.joinmobilizon.org/${PV}/${MY_P}_${ARCH}.tar.gz"

LICENSE="AGPL-3"
SLOT="0"
KEYWORDS="~arm"

RDEPEND="acct-user/mobilizon
		dev-db/postgis
		media-gfx/gifsicle
		media-gfx/imagemagick
		media-gfx/jpegoptim
		media-gfx/optipng
		media-gfx/pngquant
		media-libs/libwebp
		sys-apps/file
		virtual/httpd-basic
		!www-apps/mobilizon"

S="${WORKDIR}"

pkg_pretend() {
	ewarn "Please note that LDAP authentication support is broken in this binary release of Mobilizon:"
	ewarn "	https://framagit.org/framasoft/mobilizon/-/issues/1130"
	ewarn "If you need LDAP authentication support, please use www-apps/mobilizon instead."
}

src_install() {
	systemd_newunit mobilizon/support/systemd/mobilizon-release.service mobilizon.service
	newinitd "${FILESDIR}/mobilizon.initd" mobilizon
	dodoc -r mobilizon/support
	rm -fr mobilizon/support || die
	insinto /opt
	doins -r mobilizon
	keepdir /var/lib/mobilizon/uploads /var/lib/mobilizon/uploads/exports/csv /var/lib/mobilizon/data
	fowners -R mobilizon:mobilizon /var/lib/mobilizon/uploads /var/lib/mobilizon/uploads/exports/csv /var/lib/mobilizon/data /opt/mobilizon
	fperms 0755 \
		$(ls \
			mobilizon/erts-*/bin/* \
			mobilizon/lib/*/priv/{lib,bin}/* \
			mobilizon/lib/argon2_elixir-*/priv/argon2_nif.so \
			mobilizon/lib/eblurhash-*/priv/blurhash \
			mobilizon/lib/fast_html-*/priv/fasthtml_worker \
		| sed 's-^-/opt/-') \
		/opt/mobilizon/bin/mobilizon{,_ctl} \
		/opt/mobilizon/releases/${PV}/iex \
		/opt/mobilizon/releases/${PV}/elixir
}

pkg_postinst() {
	einfo "Please check https://docs.joinmobilizon.org/administration/install/release/#configuration for the configuration instructions"
}
