# Copyright 1999-2022 Gentoo Authors
# Distributed under the terms of the GNU General Public License v2

EAPI=7

inherit check-reqs systemd

DESCRIPTION="Web application to organize events with ActivityPub support"
HOMEPAGE="https://joinmobilizon.org/"
SRC_URI="https://framagit.org/framasoft/${PN}/-/archive/${PV}/${P}.tar.bz2
	geoip? ( https://download.db-ip.com/free/dbip-city-lite-2023-01.mmdb.gz )"

LICENSE="AGPL-3 geoip? ( CC-BY-4.0 )"
SLOT="0"
KEYWORDS="~arm"
RESTRICT="network-sandbox"
IUSE="geoip ldap"

RDEPEND="acct-user/mobilizon
		dev-db/postgis
		media-gfx/gifsicle
		media-gfx/imagemagick
		media-gfx/jpegoptim
		media-gfx/optipng
		media-gfx/pngquant
		media-libs/libwebp
		sys-apps/file
		virtual/httpd-basic
		!www-apps/mobilizon-bin"
DEPEND="dev-lang/elixir"
BDEPEND="ldap? ( <dev-lang/erlang-24.3 )
		dev-util/rebar:3
		net-libs/nodejs
		sys-apps/yarn"

CHECKREQS_MEMORY="2G"

pkg_pretend() {
	if use ldap; then
		ewarn "For LDAP support, make sure dev-lang/elixir was compiled with <dev-lang/erlang-24.3"
	fi
	if ! has_version media-gfx/imagemagick[jpeg,png,webp]; then
		ewarn "One of the jpeg, png or webp USE flags for media-gfx/imagemagick is disabled."
		ewarn "This will make ${CATEGORY}/${PN} unable to support that type of images."
	fi
}

src_prepare() {
	export MIX_ENV=prod
	mix local.rebar --force || die
	mix local.hex --force || die
	# We try to download dependencies twice because the repositories are not very stable and fail often
	mix deps.get || mix deps.get || die
	(cd js && yarn install || yarn install) || die
	default
}

src_compile() {
	export MIX_ENV=prod
	mix compile || die
	(cd js && NODE_OPTIONS="--max-old-space-size=2048" yarn run build --prod) || die
	mix phx.digest
}

src_install() {
	MIX_ENV=prod mix release || die
	cd _build/prod/rel || die
	systemd_newunit mobilizon/support/systemd/mobilizon-release.service mobilizon.service
	newinitd "${FILESDIR}/mobilizon.initd" mobilizon
	dodoc -r mobilizon/support
	rm -fr mobilizon/support || die
	insinto /opt
	doins -r mobilizon
	keepdir /var/lib/mobilizon/uploads /var/lib/mobilizon/uploads/exports/csv /var/lib/mobilizon/data
	fowners -R mobilizon:mobilizon /var/lib/mobilizon/uploads /var/lib/mobilizon/uploads/exports/csv /var/lib/mobilizon/data /opt/mobilizon
	fperms 0755 \
		$(ls \
			mobilizon/erts-*/bin/* \
			mobilizon/lib/*/priv/{lib,bin}/* \
			mobilizon/lib/argon2_elixir-*/priv/argon2_nif.so \
			mobilizon/lib/eblurhash-*/priv/blurhash \
			mobilizon/lib/fast_html-*/priv/fasthtml_worker \
		| sed 's-^-/opt/-') \
		/opt/mobilizon/bin/mobilizon{,_ctl} \
		/opt/mobilizon/releases/${PV}/iex \
		/opt/mobilizon/releases/${PV}/elixir

	if use geoip; then
		insinto "/opt/mobilizon/lib/${P}/priv/data"
		newins "${WORKDIR}/dbip-city-lite-2023-01.mmdb" GeoLite2-City.mmdb
	fi
}

pkg_postinst() {
	einfo "Please check https://docs.joinmobilizon.org/administration/install/release/#configuration for the configuration instructions"
}
